@@ -21,23 +21,22 @@
 #ifndef __CHANNEL_H__
 #define __CHANNEL_H__
 
-#define CHANNEL_FLAG_NONE		0
-#define CHANNEL_FLAG_DVB_T		0x01
-#define CHANNEL_FLAG_DVB_C		0x02
-#define CHANNEL_FLAG_DVB_S		0x03
-#define CHANNEL_FLAG_ATSC		0x04
-
 #include <linux/dvb/frontend.h>
 #include "epg_events.h"
 #include "dvb_transponder.h"
 
+#define CHANNEL_FLAG_NONE		0
+#define CHANNEL_FLAG_DVB_T		0x01
+#define CHANNEL_FLAG_DVB_C		0x02
+#define CHANNEL_FLAG_DVB_S		0x04
+#define CHANNEL_FLAG_ATSC		0x08
+
 class Channel
 {
 public:
 	Channel();
 
 	guint			channel_id;
-	guint			profile_id;
 	Glib::ustring	name;
 	guint			flags;
 	guint			sort_order;
@@ -45,13 +44,17 @@ public:
 	EpgEvents		epg_events;
 
 	// DVB Specific
-	guint service_id;
-	struct dvb_frontend_parameters frontend_parameters;
+	guint				service_id;
+	Dvb::Transponder	transponder;
 	guint get_transponder_frequency();
 
 	Glib::ustring get_text();
 };
 
-typedef std::list<Channel> ChannelList;
+class ChannelArray : public std::vector<Channel>
+{
+public:
+	gboolean contains(guint channel_id);
+};
 
 #endif
