@@ -148,6 +148,33 @@ gsize SectionParser::read_section(Demuxer& demuxer)
 	return section_length;
 }
 
+// this method takes a bitmask as supplied by the NIT-section (satellite delivery system descriptor) for the FEC_INNER and converts them to a linux-style FEC value according to EN 300 468, v 1.9.1
+fe_code_rate_t SectionParser::parse_fec_inner(guint bitmask)
+{
+	switch(bitmask)
+	{
+		case 0x01:
+			return FEC_1_2;
+		case 0x02:
+			return FEC_2_3;
+		case 0x03:
+			return FEC_3_4;
+		case 0x04:
+			return FEC_5_6;
+		case 0x05:
+			return FEC_7_8;
+		case 0x06:
+			return FEC_8_9;
+		case 0x07:
+			return FEC_AUTO; // EN 300 468 specifies this as "fec 3/5", which is apparently not supported by the linux kernel or is a typo. just setting to auto.
+		case 0x08:
+			return FEC_4_5;
+		default:
+			return FEC_AUTO;
+	}
+	return FEC_AUTO; // this should never happen. but it wouldn't hurt.
+}
+
 void SectionParser::parse_pas(Demuxer& demuxer, ProgramAssociationSection& section)
 {
 	gsize section_length = read_section(demuxer);
@@ -198,6 +225,236 @@ void SectionParser::parse_sds (Demuxer& demuxer, ServiceDescriptionSection& sect
 	}
 }
 
+
+void SectionParser::parse_nis (Demuxer& demuxer, NetworkInformationSection& section)
+{
+	gsize section_length = read_section(demuxer);
+	//dump(buffer, section_length);
+	
+	guint offset = 8;
+	guint network_descriptor_length = get_bits(buffer + offset, 4, 12);
+	offset += 2;
+	
+	// We don't care for the network descriptors, as we only want to get new frequencies out of the stream, and they are saved in the "Transport stream descriptor" section.
+	offset += network_descriptor_length;
+	
+	// Now offset is at "transport_stream_loop_length" position.
+	guint transport_stream_length = get_bits(buffer + offset, 4, 12);
+	offset += 2;
+	
+	// loop through all transport descriptors and pick out 0x43 descriptors, as they contain new frequencies.
+	while (offset < section_length - 4)
+	{
+		offset += 4;
+		guint descriptors_loop_length = get_bits(buffer + offset, 4, 12);
+		offset += 2;
+		guint descriptors_end_offset = offset + descriptors_loop_length;
+		
+		while (offset < descriptors_end_offset)
+		{
+			guint descriptor_tag = buffer[offset++];
+			guint descriptor_length = buffer[offset++];
+
+			if (descriptor_tag == 0x43)
+			{
+				g_debug("Found Satellite Delivery System Descriptor");
+
+				struct dvb_frontend_parameters frontend_parameters;
+				
+				// extract data for new transponder, according to EN 300 468: dvb-s
+				frontend_parameters.frequency = 0;
+				for (int i=0; i<8; i++)
+				{
+					frontend_parameters.frequency = frontend_parameters.frequency*10 + get_bits(buffer + offset, i*4, 4);
+				}
+				frontend_parameters.frequency *= 10;
+				
+				guint polarisation = (get_bits(buffer + offset + 6, 2, 1) == 1) ?POLARISATION_VERTICAL :POLARISATION_HORIZONTAL;
+				
+				frontend_parameters.u.qpsk.symbol_rate = 0;
+				for(int i=0; i<7; i++)
+				{
+					frontend_parameters.u.qpsk.symbol_rate = frontend_parameters.u.qpsk.symbol_rate*10 + get_bits(buffer + offset + 7, i*4, 4);
+				}
+				frontend_parameters.u.qpsk.symbol_rate *= 100;
+				
+				frontend_parameters.u.qpsk.fec_inner = parse_fec_inner(get_bits(buffer + offset + 7, 28, 4));
+				frontend_parameters.inversion = INVERSION_AUTO;
+				
+				Transponder transponder;
+				transponder.frontend_parameters = frontend_parameters;
+				transponder.polarisation = polarisation;
+				section.transponders.push_back(transponder);
+				
+				g_debug("New frequency: %d, New polarisation: %d, Symbol rate %d, fec_inner %d",
+					frontend_parameters.frequency, transponder.polarisation,
+					frontend_parameters.u.qpsk.symbol_rate, frontend_parameters.u.qpsk.fec_inner);
+			}
+			else if (descriptor_tag == 0x44)
+			{
+				Transponder transponder;
+
+				g_debug("Found Cable Delivery System Descriptor");
+
+				guint frequency = 0;
+				for (int i=0; i<8; i++)
+				{
+					frequency = frequency*10 + get_bits(buffer + offset, i*4, 4);
+				}
+				frequency *= 10;
+
+				// reserved_future_use (12)
+				guint fec_outer = get_bits(buffer + offset, 44, 4);
+				guint modulation = get_bits(buffer + offset, 48, 8);
+				guint symbol_rate = get_bits(buffer + offset, 56, 28);
+				guint fec_inner = get_bits(buffer + offset, 84, 4);
+
+				g_debug("frequency: %d", frequency);
+				g_debug("FEC_outer: %d", fec_outer);
+				g_debug("modulation: %d", modulation);
+				g_debug("symbol_rate: %d", symbol_rate);
+				g_debug("FEC_inner: %d", fec_inner);
+
+				transponder.frontend_parameters.frequency = frequency;
+				transponder.frontend_parameters.inversion = INVERSION_AUTO;
+
+				transponder.frontend_parameters.u.qam.symbol_rate = symbol_rate;
+
+				switch (modulation)
+				{
+					case 1: transponder.frontend_parameters.u.qam.modulation = QAM_16; break;
+					case 2: transponder.frontend_parameters.u.qam.modulation = QAM_32; break;
+					case 3: transponder.frontend_parameters.u.qam.modulation = QAM_64; break;
+					case 4: transponder.frontend_parameters.u.qam.modulation = QAM_128; break;
+					case 5: transponder.frontend_parameters.u.qam.modulation = QAM_256; break;
+					default: transponder.frontend_parameters.u.qam.modulation = QAM_AUTO;
+				}
+
+				switch (fec_inner)
+				{
+					case 1: transponder.frontend_parameters.u.qam.fec_inner = FEC_1_2; break;
+					case 2: transponder.frontend_parameters.u.qam.fec_inner = FEC_2_3; break;
+					case 3: transponder.frontend_parameters.u.qam.fec_inner = FEC_3_4; break;
+					case 4: transponder.frontend_parameters.u.qam.fec_inner = FEC_5_6; break;
+					case 5: transponder.frontend_parameters.u.qam.fec_inner = FEC_7_8; break;
+					case 6: transponder.frontend_parameters.u.qam.fec_inner = FEC_8_9; break;
+#ifdef FEC_3_5
+					case 7: transponder.frontend_parameters.u.qam.fec_inner = FEC_3_5; break;
+#endif
+					case 8: transponder.frontend_parameters.u.qam.fec_inner = FEC_4_5; break;
+#ifdef FEC_9_10
+					case 9: transponder.frontend_parameters.u.qam.fec_inner = FEC_9_10; break;
+#endif
+					default: transponder.frontend_parameters.u.qam.fec_inner = FEC_AUTO;
+				}
+
+				section.transponders.push_back(transponder);
+			}
+			else if (descriptor_tag == 0x5A)
+			{
+				Transponder transponder;
+
+				g_debug("Found Terrestrial Delivery System Descriptor");
+				guint centre_frequency = get_bits(buffer + offset, 0, 32) * 10;
+				offset += 4;
+
+				guint bandwidth = get_bits(buffer + offset, 0, 3);
+				// priority (1)
+				// Time_Slicing_indicator (1)
+				// MPE-FEC_indicator (1)
+				// reserved_future_use (2)
+				guint constellation = get_bits(buffer + offset, 9, 2);
+				guint hierarchy_information = get_bits(buffer + offset, 11, 3);
+				guint code_rate_HP = get_bits(buffer + offset, 14, 3);
+				guint code_rate_LP = get_bits(buffer + offset, 17, 3);
+				guint guard_interval = get_bits(buffer + offset, 20, 2);
+				guint transmission_mode = get_bits(buffer + offset, 22, 2);
+
+				g_debug("centre_frequency: %d", centre_frequency);
+				g_debug("bandwidth: %d", bandwidth);
+				g_debug("constellation: %d", constellation);
+				g_debug("hierarchy_information: %d", hierarchy_information);				
+				g_debug("code_rate_HP: %d", code_rate_HP);
+				g_debug("code_rate_LP: %d", code_rate_LP);
+				g_debug("guard_interval: %d", guard_interval);
+				g_debug("transmission_mode: %d", transmission_mode);
+
+				transponder.frontend_parameters.frequency = centre_frequency;
+				transponder.frontend_parameters.inversion = INVERSION_AUTO;
+					
+				switch (bandwidth)
+				{
+					case 0: transponder.frontend_parameters.u.ofdm.bandwidth = BANDWIDTH_8_MHZ; break;
+					case 1: transponder.frontend_parameters.u.ofdm.bandwidth = BANDWIDTH_7_MHZ; break;
+					case 2: transponder.frontend_parameters.u.ofdm.bandwidth = BANDWIDTH_6_MHZ; break;
+					default: transponder.frontend_parameters.u.ofdm.bandwidth = BANDWIDTH_AUTO;
+				}
+
+				switch (constellation)
+				{
+					case 1: transponder.frontend_parameters.u.ofdm.constellation = QAM_16; break;
+					case 2: transponder.frontend_parameters.u.ofdm.constellation = QAM_64; break;
+					default: transponder.frontend_parameters.u.ofdm.constellation = QAM_AUTO;
+				}
+
+				switch (hierarchy_information)
+				{
+					case 0: case 4: transponder.frontend_parameters.u.ofdm.hierarchy_information = HIERARCHY_NONE; break;
+					case 1: case 5: transponder.frontend_parameters.u.ofdm.hierarchy_information = HIERARCHY_1; break;
+					case 2: case 6: transponder.frontend_parameters.u.ofdm.hierarchy_information = HIERARCHY_2; break;
+					case 3: case 7: transponder.frontend_parameters.u.ofdm.hierarchy_information = HIERARCHY_4; break;
+					default: transponder.frontend_parameters.u.ofdm.hierarchy_information = HIERARCHY_AUTO;
+				}
+
+				switch (code_rate_HP)
+				{
+					case 0: transponder.frontend_parameters.u.ofdm.code_rate_HP = FEC_1_2; break;
+					case 1: transponder.frontend_parameters.u.ofdm.code_rate_HP = FEC_2_3; break;
+					case 2: transponder.frontend_parameters.u.ofdm.code_rate_HP = FEC_3_4; break;
+					case 3: transponder.frontend_parameters.u.ofdm.code_rate_HP = FEC_5_6; break;
+					case 4: transponder.frontend_parameters.u.ofdm.code_rate_HP = FEC_7_8; break;
+					default: transponder.frontend_parameters.u.ofdm.code_rate_HP = FEC_AUTO;
+				}
+
+				switch (code_rate_LP)
+				{
+					case 0: transponder.frontend_parameters.u.ofdm.code_rate_LP = FEC_1_2; break;
+					case 1: transponder.frontend_parameters.u.ofdm.code_rate_LP = FEC_2_3; break;
+					case 2: transponder.frontend_parameters.u.ofdm.code_rate_LP = FEC_3_4; break;
+					case 3: transponder.frontend_parameters.u.ofdm.code_rate_LP = FEC_5_6; break;
+					case 4: transponder.frontend_parameters.u.ofdm.code_rate_LP = FEC_7_8; break;
+					default: transponder.frontend_parameters.u.ofdm.code_rate_LP = FEC_AUTO;
+				}
+
+				switch (guard_interval)
+				{
+					case 0: transponder.frontend_parameters.u.ofdm.guard_interval = GUARD_INTERVAL_1_32; break;
+					case 1: transponder.frontend_parameters.u.ofdm.guard_interval = GUARD_INTERVAL_1_16; break;
+					case 2: transponder.frontend_parameters.u.ofdm.guard_interval = GUARD_INTERVAL_1_8; break;
+					case 3: transponder.frontend_parameters.u.ofdm.guard_interval = GUARD_INTERVAL_1_4; break;
+					default: transponder.frontend_parameters.u.ofdm.guard_interval = GUARD_INTERVAL_AUTO;
+				}
+
+				switch (transmission_mode)
+				{
+					case 0: transponder.frontend_parameters.u.ofdm.transmission_mode = TRANSMISSION_MODE_2K; break;
+					case 1: transponder.frontend_parameters.u.ofdm.transmission_mode = TRANSMISSION_MODE_8K; break;
+					default: transponder.frontend_parameters.u.ofdm.transmission_mode = TRANSMISSION_MODE_AUTO;
+				}
+
+				section.transponders.push_back(transponder);
+			}
+			else
+			{
+				g_debug("Ignoring descriptor tag 0x%02X", descriptor_tag);
+			}
+			offset += descriptor_length;
+		}
+	}
+	
+	g_debug("transport_stream_length is %d, network_descriptor_length is %d and offset is %d", transport_stream_length, network_descriptor_length, offset);
+}
+
 gsize get_atsc_text(Glib::ustring& string, const guchar* buffer)
 {
 	size_t text_position = 0;
@@ -446,7 +703,7 @@ void SectionParser::parse_psip_eis(Demuxer& demuxer, EventInformationSection& se
 		{
 			EventText event_text;
 			get_atsc_text (event_text.title, &buffer[offset++]);
-			event.texts.push_back(event_text);
+			event.texts[event_text.language] = event_text;
 			offset += title_length;
 		}
 		
@@ -474,7 +731,7 @@ void SectionParser::parse_eis(Demuxer& demuxer, EventInformationSection& section
 	section.last_table_id =					get_bits (buffer, 104, 8);
 
 	unsigned int offset = 14;
-	
+
 	while (offset < (section_length - CRC_BYTE_SIZE))
 	{
 		Event event;
@@ -489,7 +746,7 @@ void SectionParser::parse_eis(Demuxer& demuxer, EventInformationSection& section
 		duration				= get_bits (&buffer[offset], 56, 24);
 		event.running_status	= get_bits (&buffer[offset], 80, 3);
 		event.free_CA_mode		= get_bits (&buffer[offset], 83, 1);
-
+		
 		unsigned int descriptors_loop_length  = get_bits (&buffer[offset], 84, 12);
 		offset += 12;
 		unsigned int end_descriptor_offset = descriptors_loop_length + offset;
@@ -531,7 +788,7 @@ void SectionParser::parse_eis(Demuxer& demuxer, EventInformationSection& section
 			t.tm_year	= event_start_year - 1900;
 			
 			event.start_time = mktime(&t);
-		
+
 			while (offset < end_descriptor_offset)
 			{
 				offset += decode_event_descriptor(&buffer[offset], event);
@@ -542,7 +799,7 @@ void SectionParser::parse_eis(Demuxer& demuxer, EventInformationSection& section
 				throw Exception(_("ASSERT: offset > end_descriptor_offset"));
 			}
 
-			section.events.push_back( event );
+			section.events.push_back(event);
 		}
 	}
 	section.crc = get_bits (&buffer[offset], 0, 32);
@@ -571,44 +828,80 @@ gsize SectionParser::decode_event_descriptor (const guchar* event_buffer, Event&
 			Glib::ustring language;
 			Glib::ustring title;
 			Glib::ustring description;
-			Glib::ustring temp_description;
 			Glib::ustring temp_title;
+			Glib::ustring temp_description;
 
-			language = get_lang_desc (event_buffer);
+			language = get_lang_desc (event_buffer + 1);
+			
+			if (!event.texts.contains(language))
+			{
+				EventText event_text_temp;
+				event.texts[language] = event_text_temp;
+				event_text_temp.language = language;
+			}
+			EventText& event_text = event.texts[language];
+			
 			unsigned int offset = 6;
 			guint length_of_items = event_buffer[offset];
 			offset++;
 			while (length_of_items > offset - 7)
 			{
 				offset += get_text(temp_description, &event_buffer[offset]);			
-				description += temp_description;
+				if (temp_description != "-")
+				{
+					description += temp_description;
+				}
 
 				offset += get_text(temp_title, &event_buffer[offset]);
-				title += temp_title;
+				if (temp_title != "-")
+				{
+					title += temp_title;
+				}
 			}
 			offset += get_text(temp_description, &event_buffer[offset]);
-			description += temp_description;
+			if (temp_description != "-")
+			{
+				description	+= temp_description;
+			}
 			
-			EventText event_text;
-			event_text.is_extended = true;
-			event_text.language = language;
-			event_text.description += description;
-			event_text.title += title;
+			if (!event_text.is_extended)
+			{
+				event_text.description.clear();
+			}
 			
-			event.texts.push_back(event_text);
+			event_text.is_extended	= true;
+			event_text.title		+= title;
+			event_text.description	+= description;
 		}
 		break;
 
 	case SHORT_EVENT:
 		{
-			EventText event_text;
+			Glib::ustring	language;
+			Glib::ustring	title;
+			Glib::ustring	description;
+			
+			language = get_lang_desc (event_buffer);
+			if (!event.texts.contains(language))
+			{
+				EventText event_text_temp;
+				event.texts[language] = event_text_temp;
+				event_text_temp.language = language;
+			}
+			EventText& event_text = event.texts[language];
+
 			event_text.is_extended = false;
-			event_text.language = get_lang_desc (event_buffer);
+			event_text.language = language;
 			unsigned int offset = 5;
-			offset += get_text(event_text.title, &event_buffer[offset]);
-			offset += get_text(event_text.description, &event_buffer[offset]);
-					
-			event.texts.push_back(event_text);
+			offset += get_text(title, &event_buffer[offset]);
+			offset += get_text(description, &event_buffer[offset]);
+			
+			event_text.title = title;
+
+			if (!event_text.is_extended)
+			{
+				event_text.description += description;
+			}
 		}
 		break;
 	default:
@@ -631,7 +924,6 @@ guint SectionParser::get_bits(const guchar* b, guint bitpos, gsize bitcount)
 	return val;
 }
 
-
 gsize SectionParser::get_text(Glib::ustring& s, const guchar* text_buffer)
 {
 	gsize length = text_buffer[0];
@@ -645,7 +937,7 @@ gsize SectionParser::get_text(Glib::ustring& s, const guchar* text_buffer)
 		// Skip over length byte
 		index++;
 
-		if (text_encoding != "auto")
+		if (text_encoding.length() > 0 && text_encoding != "auto")
 		{
 			codeset = text_encoding.c_str();
 		}
@@ -750,7 +1042,7 @@ gsize SectionParser::get_text(Glib::ustring& s, const guchar* text_buffer)
 				gsize bytes_read;
 				gsize bytes_written;
 				GError* error = NULL;
-
+				
 				gchar* result = g_convert(
 					text,
 					text_index,
@@ -759,10 +1051,18 @@ gsize SectionParser::get_text(Glib::ustring& s, const guchar* text_buffer)
 					&bytes_read,
 					&bytes_written,
 					&error);
-
-				if (error != NULL)
+				
+				if (error != NULL || result == NULL)
 				{
-					Glib::ustring message = Glib::ustring::compose(_("Failed to convert to UTF-8: %1"), error->message);
+					const gchar* error_message = _("No message");
+					if (error != NULL)
+					{
+						error_message = error->message;
+					}
+					
+					Glib::ustring message = Glib::ustring::compose(
+						_("Failed to convert to UTF-8: %1"),
+						Glib::ustring(error_message));
 					g_debug("%s", message.c_str());
 					g_debug("Codeset: %s", codeset);
 					g_debug("Length: %zu", length);
@@ -771,20 +1071,16 @@ gsize SectionParser::get_text(Glib::ustring& s, const guchar* text_buffer)
 						gchar ch = text_buffer[i];
 						if (!isprint(ch))
 						{
-							g_debug("text_buffer[%d]\t= 0x%02X", i, text_buffer[i]);
+							g_debug("text_buffer[%d]\t= 0x%02X", i, ch);
 						}
 						else
 						{
-							g_debug("text_buffer[%d]\t= 0x%02X '%c'", i, text_buffer[i], text_buffer[i]);
+							g_debug("text_buffer[%d]\t= 0x%02X '%c'", i, ch, ch);
 						}
 					}
 					throw Exception(message);
 				}
 				
-				if (result == NULL)
-				{
-					throw Exception(_("Failed to convert to UTF-8"));
-				}
 				s = result;
 				g_free(result);
 			}
@@ -1070,3 +1366,16 @@ Glib::ustring SectionParser::convert_iso6937(const guchar* text_buffer, gsize le
 	}
 	return result;
 }
+
+gboolean EventTextMap::contains(const Glib::ustring& language)
+{
+	for (const_iterator i = begin(); i != end(); i++)
+	{
+		if (i->first == language)
+		{
+			return true;
+		}
+	}
+	
+	return false;
+}
