@@ -25,7 +25,9 @@
 #include <map>
 #include <iostream>
 #include <fstream>
+#include <linux/dvb/frontend.h>
 #include "dvb_demuxer.h"
+#include "dvb_transponder.h"
 #include "me-tv.h"
 #include "me-tv-i18n.h"
 
@@ -33,12 +35,14 @@
 #define DVB_SECTION_BUFFER_SIZE	16*1024
 
 #define PAT_PID		0x00
+#define NIT_PID		0x10
 #define SDT_PID		0x11
 #define EIT_PID		0x12
 #define PSIP_PID	0x1FFB
 
 #define PAT_ID		0x00
 #define PMT_ID		0x02
+#define NIT_ID			0x40
 #define SDT_ID		0x42
 #define EIT_ID		0x4E
 #define MGT_ID		0xC7
@@ -62,7 +66,11 @@ namespace Dvb
 			Glib::ustring description;
 		};
 		
-		typedef std::list<EventText> EventTextList;
+		class EventTextMap : public std::map<Glib::ustring, EventText>
+		{
+		public:
+			gboolean contains(const Glib::ustring& language);
+		};
 		
 		class Event
 		{
@@ -75,7 +83,7 @@ namespace Dvb
 			guint	running_status;
 			guint	free_CA_mode;
 			
-			EventTextList texts;
+			EventTextMap texts;
 		};
 
 		typedef std::list<Event> EventList;
@@ -113,6 +121,12 @@ namespace Dvb
 			guint transport_stream_id;
 			std::vector<Service> services;
 		};
+
+		class NetworkInformationSection
+		{
+		public:
+			std::vector<Dvb::Transponder> transponders;
+		};
 		
 		class ProgramAssociation
 		{
@@ -232,12 +246,13 @@ namespace Dvb
 			Glib::ustring text_encoding;
 				
 			Glib::ustring get_lang_desc(const guchar* buffer);
-			gboolean find_descriptor(uint8_t tag, const unsigned char *buf, int descriptors_loop_len,
-				const unsigned char **desc, int *desc_len);
+			gboolean find_descriptor(uint8_t tag, const unsigned char *buf, int descriptors_loop_len, const unsigned char **desc, int *desc_len);
 			guint get_bits(const guchar* buffer, guint bitpos, gsize bitcount);
 			Glib::ustring convert_iso6937(const guchar* buffer, gsize length);
 			gsize decode_event_descriptor (const guchar* buffer, Event& event);
 			gsize read_section(Demuxer& demuxer);
+		
+			fe_code_rate_t parse_fec_inner(guint bitmask);
 		public:
 			SectionParser();
 			
@@ -250,6 +265,7 @@ namespace Dvb
 			void parse_psip_eis (Demuxer& demuxer, EventInformationSection& section);
 			void parse_psip_mgt(Demuxer& demuxer, MasterGuideTable& table);
 			void parse_sds (Demuxer& demuxer, ServiceDescriptionSection& section);
+			void parse_nis (Demuxer& demuxer, NetworkInformationSection& section);
 		};
 	}
 }
