@@ -22,6 +22,7 @@
 #define __EPG_EVENTS_H__
 
 #include "epg_event.h"
+#include "data.h"
 
 typedef std::list<EpgEvent> EpgEventList;
 
@@ -32,15 +33,18 @@ private:
 	Glib::StaticRecMutex	mutex;
 	
 	gboolean exists(const EpgEvent& epg_event);
+	void set_saved(guint epg_event_id);
 public:
 	EpgEvents();
 	~EpgEvents();
 		
-	gboolean insert(const EpgEvent& epg_event);
-	void insert(const EpgEventList& epg_event_list);
-	gboolean get_current(EpgEvent& epg_event);
-	EpgEventList get_list(gboolean update_save = false);
-	void prune();
+	gboolean			add_epg_event(const EpgEvent& epg_event);
+	void				add_epg_events(const EpgEventList& epg_event_list);
+	gboolean			get_current(EpgEvent& epg_event);
+	const EpgEventList	get_list();
+	void				prune();
+	void				load(Data::Connection& connection, guint channel_id);
+	void				save(Data::Connection& connection, guint channel_id);
 };
 
-#endif
\ No newline at end of file
+#endif
