@@ -20,33 +20,48 @@
 
 #include "scheduled_recording_dialog.h"
 #include "scheduled_recordings_dialog.h"
-#include "main_window.h"
 #include "application.h"
+#include <iomanip>
 
-ScheduledRecordingDialog* ScheduledRecordingDialog::create(Glib::RefPtr<Gnome::Glade::Xml> glade)
+ScheduledRecordingDialog& ScheduledRecordingDialog::create(Glib::RefPtr<Gtk::Builder> builder)
 {
 	ScheduledRecordingDialog* scheduled_recording_dialog = NULL;
-	glade->get_widget_derived("dialog_scheduled_recording", scheduled_recording_dialog);
-	return scheduled_recording_dialog;
+	builder->get_widget_derived("dialog_scheduled_recording", scheduled_recording_dialog);
+	return *scheduled_recording_dialog;
 }
 
-ScheduledRecordingDialog::ScheduledRecordingDialog(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& glade_xml) :
-	Gtk::Dialog(cobject), glade(glade_xml)
+ScheduledRecordingDialog::ScheduledRecordingDialog(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder) :
+	Gtk::Dialog(cobject), builder(builder)
 {
 	channel_combo_box = NULL;
 	scheduled_recording_id = 0;
-	const Profile& profile = get_application().get_profile_manager().get_current_profile();
 	
-	date_edit_start_time = dynamic_cast<Gnome::UI::DateEdit*>(glade->get_widget("date_edit_start_time"));
-	entry_description = dynamic_cast<Gtk::Entry*>(glade->get_widget("entry_description"));
-	glade->get_widget_derived("combo_box_channel", channel_combo_box);
-	channel_combo_box->load(profile.get_channels());
-	spinbutton_duration = dynamic_cast<Gtk::SpinButton*>(glade->get_widget("spinbutton_duration"));
+	builder->get_widget("entry_description", entry_description);
+	builder->get_widget_derived("combo_box_channel", channel_combo_box);
+	channel_combo_box->load(get_application().channel_manager.get_channels());
+	builder->get_widget("calendar_start_time_date", calendar_start_time_date);
+	builder->get_widget("spin_button_start_time_hour", spin_button_start_time_hour);
+	builder->get_widget("spin_button_start_time_minute", spin_button_start_time_minute);
+	builder->get_widget("spinbutton_duration", spin_button_duration);
+}
 
-	if (get_application().get_boolean_configuration_value("use_24_hour_workaround"))
+void ScheduledRecordingDialog::set_date_time(time_t t)
+{
+	if (t == 0)
 	{
-		date_edit_start_time->set_flags(date_edit_start_time->get_flags() | Gnome::UI::DATE_EDIT_24_HR);
+		t = time(NULL);
 	}
+	else
+	{
+		t = convert_to_utc_time(t);
+	}
+	
+	struct tm* start_time = localtime(&t);
+	spin_button_start_time_hour->set_value(start_time->tm_hour);
+	spin_button_start_time_minute->set_value(start_time->tm_min);
+
+	calendar_start_time_date->select_day(start_time->tm_mday);
+	calendar_start_time_date->select_month(start_time->tm_mon, 1900 + start_time->tm_year);
 }
 
 gint ScheduledRecordingDialog::run(Gtk::Window* transient_for, ScheduledRecording& scheduled_recording)
@@ -59,8 +74,9 @@ gint ScheduledRecordingDialog::run(Gtk::Window* transient_for, ScheduledRecordin
 	channel_combo_box->set_selected_channel_id(scheduled_recording.channel_id);
 	scheduled_recording_id = scheduled_recording.scheduled_recording_id;
 	entry_description->set_text(scheduled_recording.description);
-	date_edit_start_time->set_time(scheduled_recording.start_time);
-	spinbutton_duration->set_value(scheduled_recording.duration/60);
+	set_date_time(convert_to_local_time((time_t)scheduled_recording.start_time));
+	spin_button_duration->set_value(scheduled_recording.duration/60);
+	
 	return run(transient_for, false);
 }
 
@@ -77,8 +93,9 @@ gint ScheduledRecordingDialog::run(Gtk::Window* transient_for, EpgEvent& epg_eve
 
 	channel_combo_box->set_selected_channel_id(epg_event.channel_id);
 	entry_description->set_text(epg_event.get_title());
-	date_edit_start_time->set_time(convert_to_utc_time(epg_event.start_time) - (before * 60));
-	spinbutton_duration->set_value((epg_event.duration/60) + before + after);
+	set_date_time((time_t)epg_event.start_time - (before * 60));
+	spin_button_duration->set_value((epg_event.duration/60) + before + after);
+	
 	return run(transient_for, false);
 }
 
@@ -91,16 +108,13 @@ gint ScheduledRecordingDialog::run(Gtk::Window* transient_for, gboolean populate
 	
 	if (populate_default)
 	{
-		Channel* channel = get_application().get_profile_manager().get_current_profile().get_display_channel();
-		if (channel == NULL)
-		{
-			throw Exception(_("Failed to create scheduled recording dialog: No display channel"));
-		}
-		
-		channel_combo_box->set_selected_channel_id(channel->channel_id);
+		Channel& channel = get_application().channel_manager.get_display_channel();		
+		channel_combo_box->set_selected_channel_id(channel.channel_id);
 		entry_description->set_text(_("Unknown description"));
-		date_edit_start_time->set_time(time(NULL));
-		spinbutton_duration->set_value(30);
+
+		set_date_time(0);
+
+		spin_button_duration->set_value(30);
 	}
 	
 	gint dialog_response = Gtk::Dialog::run();
@@ -108,10 +122,8 @@ gint ScheduledRecordingDialog::run(Gtk::Window* transient_for, gboolean populate
 	
 	if (dialog_response == Gtk::RESPONSE_OK)
 	{
-		Data data;
 		ScheduledRecording scheduled_recording = get_scheduled_recording();
-		data.replace_scheduled_recording(scheduled_recording);
-		get_application().check_scheduled_recordings(data);
+		get_application().scheduled_recording_manager.set_scheduled_recording(scheduled_recording);
 	}
 	
 	return dialog_response;
@@ -119,12 +131,21 @@ gint ScheduledRecordingDialog::run(Gtk::Window* transient_for, gboolean populate
 
 ScheduledRecording ScheduledRecordingDialog::get_scheduled_recording()
 {
+	Glib::Date date;
+	struct tm start_time;
+
+	calendar_start_time_date->get_date(date);
+	date.to_struct_tm(start_time);
+	start_time.tm_hour = spin_button_start_time_hour->get_value();
+	start_time.tm_min = spin_button_start_time_minute->get_value();
+	
 	ScheduledRecording scheduled_recording;
-	scheduled_recording.scheduled_recording_id = scheduled_recording_id;
-	scheduled_recording.description = entry_description->get_text();
-	scheduled_recording.type = 0;
-	scheduled_recording.channel_id = channel_combo_box->get_selected_channel_id();
-	scheduled_recording.start_time = date_edit_start_time->get_time();
-	scheduled_recording.duration = spinbutton_duration->get_value() * 60;
+	scheduled_recording.scheduled_recording_id	= scheduled_recording_id;
+	scheduled_recording.description				= entry_description->get_text();
+	scheduled_recording.type					= 0;
+	scheduled_recording.channel_id				= channel_combo_box->get_selected_channel_id();
+	scheduled_recording.start_time				= mktime(&start_time);
+	scheduled_recording.duration				= (int)spin_button_duration->get_value() * 60;
+	scheduled_recording.device					= get_application().device_manager.get_frontend().get_path();
 	return scheduled_recording;
 }
