@@ -22,22 +22,20 @@
 #define __STATUS_ICON_H__
 
 #include <libgnomeuimm.h>
-#include <libglademm.h>
 
 class StatusIcon
 {
 private:
-	Glib::RefPtr<Gnome::Glade::Xml> glade;
 	Glib::RefPtr<Gtk::StatusIcon>	status_icon;
-	Gtk::Menu*						popup_menu;
+	Gtk::Menu*						menu_status;
 		
 	void on_popup_menu(guint button, guint32 activate_time);
-	void on_menu_item_me_tv_clicked();
-	void on_menu_item_popup_quit_clicked();
+	void on_menu_item_status_quit_clicked();
+	void on_menu_item_status_me_tv_clicked();
 	void on_activate();
 
 public:
-	StatusIcon(Glib::RefPtr<Gnome::Glade::Xml>& glade);
+	StatusIcon();
 	void update();
 };
 
